import 'dart:async';
import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:http/http.dart';

import 'api_exceptions.dart';

class ApiBase {
  Future<dynamic> get(Uri url, Map<String, String> parameters) async {
    var apiResponse;
    try {
      final response = await http.get(url);
      apiResponse = _returnResponse(response.body.toString(), response.statusCode);
    } on SocketException {
      throw FetchDataException('No Internet connection');
    }
    return apiResponse;
  }

  Future<dynamic> post(Uri url, dynamic body) async {
    var apiResponse;
    try {
      final response = await http.post(url, body: body);
      apiResponse = _returnResponse(response.body.toString(), response.statusCode);
    } on SocketException {
      throw FetchDataException('No Internet connection');
    }
    return apiResponse;
  }

  Future<dynamic> put(Uri url, dynamic body) async {
    var apiResponse;
    try {
      final response = await http.put(url, body: body);
      apiResponse = _returnResponse(response.body.toString(), response.statusCode);
    } on SocketException {
      throw FetchDataException('No Internet connection');
    }
    return apiResponse;
  }

  Future<dynamic> delete(Uri url, Map<String, String> parameters) async {
    var apiResponse;
    try {
      final response = await http.delete(url);
      apiResponse = _returnResponse(response.body.toString(), response.statusCode);
    } on SocketException {
      throw FetchDataException('No Internet connection');
    }
    return apiResponse;
  }

  Future<dynamic> multiPart(MultipartRequest request) async {
    var responseJson;
    try {
      var response = await request.send();
      var string = await response.stream.bytesToString();
      responseJson = _returnResponse(string, response.statusCode);
    } on SocketException {
      throw FetchDataException('No Internet connection');
    }
    return responseJson;
  }
}

dynamic _returnResponse(String response, int status) {
  switch (status) {
    case 200:
      try {
        var responseJson = json.decode(response);
        return responseJson;
      } on Exception {
        throw BadResponseException(response);
      }

      break;
    case 400:
      throw BadRequestException(response);
    case 401:
      throw UnauthorisedException(response);
    case 403:
      throw UnauthorisedException(response);
    case 500:
    default:
      print(response);
      throw FetchDataException('Error occured while Communication with Server with StatusCode : $status');
  }
}
