import 'dart:io';

import 'package:flutter/foundation.dart';

class Info {
  static ApplicationProfile getApplicationProfile() {
    if (kReleaseMode) {
      return ApplicationProfile.release;
    }
    if (kDebugMode) {
      return ApplicationProfile.debug;
    }
    if (kProfileMode) {
      return ApplicationProfile.profile;
    }

    ///Fallback
    return ApplicationProfile.debug;
  }

  /// Check if current platform is web
  static bool isWeb() => kIsWeb;

  /// Check if current platform is android
  static bool isAndroid() => Platform.isAndroid;

  /// Check if current platform is ios
  static bool isIos() => Platform.isIOS;

  static bool isLinux() => Platform.isLinux;

  static bool isMac() => Platform.isMacOS;

  static bool isWindows() => Platform.isWindows;

  static PlatformType getPlatformType() {
    if (isWeb()) {
      return PlatformType.Web;
    }
    if (isAndroid()) {
      return PlatformType.Android;
    }
    if (isIos()) {
      return PlatformType.iOS;
    }
    if (isLinux()) {
      return PlatformType.Linux;
    }
    if (isMac()) {
      return PlatformType.Mac;
    }
    if (isWindows()) {
      return PlatformType.Windows;
    }
    return PlatformType.Unknown;
  }
}

enum PlatformType { Android, iOS, Web, Linux, Windows, Mac, Unknown }

enum ApplicationProfile { debug, release, profile }
