import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

class Navigation {
  static Future<T?> push<T>(BuildContext context, Widget page) {
    NavigatorState nvState = Navigator.of(context);

    return nvState.push<T>(
      new MaterialPageRoute(builder: (context) => page),
    );
  }

  static void pushNamed(BuildContext context, String page) {
    if (context == null) return;
    Navigator.of(context).pushNamed(page);
  }

  static Future<T?> popAndPush<T>(BuildContext context, Widget page) {
    pop(context);
    return Navigator.of(context).push(
      new MaterialPageRoute(builder: (context) => page),
    );
  }

  static void popsAndPush(BuildContext context, Widget page) {
    pops(context);
    push(context, page);
  }

  static void replace(BuildContext context, Widget page) {
    if (context == null) return;
    Navigator.of(context).pushReplacement(
      new MaterialPageRoute(builder: (context) => page),
    );
  }

  static void makeFirst(BuildContext context, Widget page) {

    NavigatorState nvState = Navigator.of(context);

    if (nvState == null) {
      return;
    }

    nvState.popUntil((predicate) => predicate.isFirst);
    nvState.pushReplacement(
      new MaterialPageRoute(builder: (context) {
        // appContext = context;
        return page;
      }),
    );
  }

  static void pop<T extends Object>(BuildContext context, [T? result]) {
    if (Navigator.of(context).canPop()) {
      Navigator.of(context).pop(result);
    }
  }

  static void pops(BuildContext context) {
    if (context == null) return;

    NavigatorState nvState = Navigator.of(context);

    if (nvState == null) {
      return;
    }

    if (nvState.canPop()) {
      nvState.popUntil((predicate) => predicate.isFirst);
    }
  }

  static void dismissAlert(context) {
    pop(context);
  }

  static void navigate(BuildContext context, String page) {
    if (context == null) return;
    // appContext = context;
    Navigator.of(context).popUntil((predicate) => predicate.isFirst);
    Navigator.of(context).pushReplacementNamed(page);
  }
}
